@@ -2,6 +2,7 @@ from api_manager.async_response.lazy_request import lazy_request
 from api_manager.constants import Project, APIState, Entities
 from api_manager.methods import get, post, put, patch, delete
 from api_manager.token import get_alms_token, get_labs_token
+from api_manager.utils import prettify_json
 
 __all__ = [
     'get_alms_token',
@@ -14,5 +15,6 @@ __all__ = [
     'lazy_request',
     'Project',
     'APIState',
-    'Entities'
+    'Entities',
+    'prettify_json'
 ]
