@@ -6,6 +6,8 @@ from shlex import quote
 
 import allure
 
+from api_manager.settings import LIBRARY_ROOT
+
 
 def logging_response(response):
     """
@@ -110,5 +112,5 @@ def response_log_message(response):
         'curl': to_curl(response.request, verify=False)
     }
 
-    with open('./templates/log_template.html', 'r') as template:
+    with open(LIBRARY_ROOT + '/templates/log_template.html', 'r') as template:
         return str(template.read()).format(**payload)
